SUCCESS_STATUS = 0
FAILURE_STATUS = 1

TXT_FORMAT = [".txt", ".rtf"]

PDF_FORMAT = [".pdf"]

DOC_FORMAT = [".doc", ".docx"]
XLS_FORMAT = [".xls", ".xlsx"]

IMAGE_FORMAT = [".jpg", ".webp", ".bmp", ".pcx", ".tif", ".gif", ".jpeg", ".tga", ".exif", ".fpx", ".svg", ".psd",
                ".cdr", ".pcd", ".dxf", ".ufo", ".eps", ".ai", ".png", ".hdri", ".raw", ".wmf", ".flic", ".emf", ".ico",
                ".avif"]
